@@ -173,13 +173,10 @@ class DatabaseManager:
                     continue
             filtered_columns.append((table, col, typ))
 
-        if not fields_to_include and not fields_to_exclude:
-            filtered_columns = columns
-
         with get_cursor(conn) as cursor:
             for table, col, typ in filtered_columns:
                 cursor.execute(
-                    f"SELECT `{col}` FROM `{table}` WHERE `{col}` IS NOT NULL ORDER BY RAND() LIMIT %s",
+                    f"SELECT DISTINCT `{col}` FROM `{table}` WHERE `{col}` IS NOT NULL ORDER BY RAND() LIMIT %s",
                     (num_examples,)
                 )
                 samples = [row[0] for row in cursor.fetchall()]
